@@ -632,12 +632,14 @@ QC_Histogram <- function(
   }
 
   # Check and set titles
-  if (is.null(x = plot_title) && is.null(x = split.by)) {
-    plot_titles <- all_found_features
+  if (!is.null(x = plot_title) && length(x = plot_title) != length(x = features)) {
+    cli_abort(message = "The number of {.code plot_title} (.field {length(x = plot_title)}}) does not equal number of features ({.field {length(x = all_found_features)}})")
+  } else {
+    plot_titles <- plot_title
   }
 
-  if (!is.null(x = plot_title) && length(x = plot_title) != features) {
-    cli_abort(message = "The number of {.code plot_title} (.field {length(x = plot_title)}}) does not equal number of features ({.field {length(x = all_found_features)}})")
+  if (is.null(x = plot_title) && is.null(x = split.by)) {
+    plot_titles <- all_found_features
   }
 
   # Plot
